@@ -32,7 +32,10 @@ class MagicCallLogger(APIRoute):
             }
             await make_call_from_request_and_response(request, response, error, times)
             if error:
-                save_tasks()
+                try:
+                    save_tasks()
+                except Exception as save_task_error:
+                    print('[ERROR] save task error', save_task_error)
                 raise error
             return response
 
